@@ -1,5 +1,5 @@
 package YAMLScript::Str;
-use Mo qw'xxx';
+use Mo qw(xxx);
 
 use YAMLScript::NS;
 
@@ -7,15 +7,14 @@ sub val {
     my ($self) = (@_);
     my $value = $$self;
     my $ns = YAMLScript::NS::ns();
-    my $vars = $ns->vars;
     $value =~ s{
         \$(\w+)
     }{
-        $vars->{$1} //
+        $ns->{$1} //
         ZZZ [
-            $vars,
+            # $ns,
             "Can't find '$1' in namepspace vars",
-        ];;
+        ];
     }gex;
     $value;
 }
